@@ -549,11 +549,13 @@ clearlooks_style_draw_box (DRAW_ARGS)
 			                                      widget, &column_index, &columns,
 			                                      &resizable);
 		}
+#ifndef GTK_DISABLE_DEPRECATED
 		else if (GE_IS_CLIST (widget->parent))
 		{
 			clearlooks_clist_get_header_index (GTK_CLIST(widget->parent),
 			                                   widget, &column_index, &columns);
 		}
+#endif
 
 		header.resizable = resizable;
 
@@ -579,7 +581,6 @@ clearlooks_style_draw_box (DRAW_ARGS)
 	{
 	
 		WidgetParameters params;
-		ShadowParameters shadow = { CR_CORNER_ALL, CL_SHADOW_NONE } ;
 		clearlooks_set_widget_parameters (widget, style, state_type, &params);
 		params.active = shadow_type == GTK_SHADOW_IN;
 
@@ -590,8 +591,6 @@ clearlooks_style_draw_box (DRAW_ARGS)
 			else
 				params.corners = CR_CORNER_TOPLEFT | CR_CORNER_BOTTOMLEFT;
 
-			shadow.shadow = CL_SHADOW_IN;
-
 			if (params.xthickness > 2)
 			{
 				if (params.ltr)
@@ -606,8 +605,38 @@ clearlooks_style_draw_box (DRAW_ARGS)
 				params.enable_shadow = TRUE;
 		}
 
-		STYLE_FUNCTION(draw_button) (cr, &clearlooks_style->colors, &params,
-		                             x, y, width, height);
+		if (shadow_type != GTK_SHADOW_ETCHED_IN)
+		{
+			STYLE_FUNCTION(draw_button) (cr, &clearlooks_style->colors, &params,
+			                             x, y, width, height);
+		}
+		else
+		{
+			g_print ("ETCHED IN\n");
+			cairo_save (cr);
+			cairo_move_to (cr, x, y);
+			cairo_line_to (cr, x + width, y);
+			cairo_line_to (cr, x, y + height);
+			cairo_close_path (cr);
+			cairo_clip (cr);
+			params.active = TRUE;
+			params.state_type = GTK_STATE_ACTIVE;
+			STYLE_FUNCTION(draw_button) (cr, &clearlooks_style->colors, &params,
+			                             x, y, width, height);
+			cairo_restore (cr);
+
+			cairo_save (cr);
+			cairo_move_to (cr, x + width, y);
+			cairo_line_to (cr, x + width, y + height);
+			cairo_line_to (cr, x, y + height);
+			cairo_close_path (cr);
+			cairo_clip (cr);
+			params.active = FALSE;
+			params.state_type = GTK_STATE_NORMAL;
+			STYLE_FUNCTION(draw_button) (cr, &clearlooks_style->colors, &params,
+			                             x, y, width, height);
+			cairo_restore (cr);
+		}
 	}
 	else if (DETAIL ("spinbutton_up") || DETAIL ("spinbutton_down"))
 	{
@@ -778,7 +807,7 @@ clearlooks_style_draw_box (DRAW_ARGS)
 		ProgressBarParameters progressbar;
 		gdouble               elapsed = 0.0;
 
-#ifdef HAVE_ANIMATION
+#ifdef HAVE_WORKING_ANIMATION
 		if(clearlooks_style->animation && CL_IS_PROGRESS_BAR (widget))
 		{
 			gboolean activity_mode = GTK_PROGRESS (widget)->activity_mode;
@@ -796,7 +825,12 @@ clearlooks_style_draw_box (DRAW_ARGS)
 		{
 			progressbar.orientation = gtk_progress_bar_get_orientation (GTK_PROGRESS_BAR (widget));
 			progressbar.value = gtk_progress_bar_get_fraction(GTK_PROGRESS_BAR(widget));
+#ifndef GTK_DISABLE_DEPRECATED
 			progressbar.pulsing = GTK_PROGRESS (widget)->activity_mode;
+#else
+#warning Assuming non-pulsing progress bars because GTK_DISABLE_DEPRECATED is enabled.
+			progressbar.pulsing = FALSE;
+#endif
 		}
 		else
 		{
