@@ -17,11 +17,17 @@ Thinice Authors: Tim Gerla <timg@rrv.net>
 #define YTHICKNESS(style) (style->ythickness)
 #define XTHICKNESS(style) (style->xthickness)
 
-static GtkStyleClass *mist_parent_style_class = NULL;
+G_DEFINE_DYNAMIC_TYPE (MistStyle, mist_style, GTK_TYPE_STYLE)
 
 static void mist_style_init       (MistStyle      *style);
 static void mist_style_class_init (MistStyleClass *klass);
 
+void
+mist_style_register_types (GTypeModule *module)
+{
+	mist_style_register_type (module);
+}
+
 static GtkShadowType
 mist_get_shadow_type (GtkStyle *style, const char *detail, GtkShadowType requested)
 {
@@ -1155,6 +1161,14 @@ mist_style_draw_resize_grip(GtkStyle *style,
 	cairo_destroy(cr);
 }
 
+#ifndef GTK_DISABLE_DEPRECATED
+#ifndef GDK_DISABLE_DEPRECATED
+#define DISABLE_CUSTOM_STRING_DRAWING
+#warning Disabling custom string drawing so that no deprecated API is used.
+#endif /* GDK_DISABLE_DEPRECATED */
+#endif /* GTK_DISABLE_DEPRECATED */
+
+#ifndef DISABLE_CUSTOM_STRING_DRAWING
 static void
 mist_style_draw_string (GtkStyle      *style,
 	     GdkWindow     *window,
@@ -1180,6 +1194,8 @@ mist_style_draw_string (GtkStyle      *style,
 		gdk_gc_set_clip_rectangle (style->fg_gc[state_type], NULL);
 	}
 }
+#endif /* DISABLE_CUSTOM_STRING_DRAWING */
+
 
 static void
 mist_style_draw_layout (GtkStyle        *style,
@@ -1366,29 +1382,6 @@ mist_style_draw_focus (GtkStyle *style,
 	cairo_destroy (cr);
 }
 
-GType mist_type_style = 0;
-
-void
-mist_style_register_type (GTypeModule *module)
-{
-	static const GTypeInfo object_info = {
-		sizeof (MistStyleClass),
-		(GBaseInitFunc) NULL,
-		(GBaseFinalizeFunc) NULL,
-		(GClassInitFunc) mist_style_class_init,
-		NULL,           /* class_finalize */
-		NULL,           /* class_data */
-		sizeof (MistStyle),
-		0,              /* n_preallocs */
-		(GInstanceInitFunc) mist_style_init,
-	};
-	
-	mist_type_style = g_type_module_register_type (module,
-						       GTK_TYPE_STYLE,
-						       "MistStyle",
-						       &object_info, 0);
-}
-
 static void
 mist_style_init (MistStyle *style)
 {
@@ -1399,7 +1392,7 @@ mist_style_realize (GtkStyle * style)
 {
   MistStyle *mist_style = MIST_STYLE (style);
  
-  mist_parent_style_class->realize (style);
+  GTK_STYLE_CLASS (mist_style_parent_class)->realize (style);
  
   ge_gtk_style_to_cairo_color_cube (style, &mist_style->color_cube);
 }
@@ -1409,8 +1402,6 @@ mist_style_class_init (MistStyleClass *klass)
 {
 	GtkStyleClass *style_class = GTK_STYLE_CLASS (klass);
 	
-	mist_parent_style_class = g_type_class_peek_parent (klass);
-	
 	style_class->realize = mist_style_realize;
 
 	style_class->draw_hline = mist_style_draw_hline;
@@ -1427,8 +1418,15 @@ mist_style_class_init (MistStyleClass *klass)
 	style_class->draw_extension = mist_style_draw_extension;
 	style_class->draw_handle = mist_style_draw_handle;
 	style_class->draw_resize_grip = mist_style_draw_resize_grip;
+#ifndef DISABLE_CUSTOM_STRING_DRAWING
 	style_class->draw_string = mist_style_draw_string;
+#endif
 	style_class->draw_layout = mist_style_draw_layout;
 	style_class->render_icon = mist_style_render_icon;
 	style_class->draw_focus = mist_style_draw_focus;
 }
+
+static void
+mist_style_class_finalize (MistStyleClass *klass)
+{
+}
